from django.db import models


class Publication(models.Model):
    BOOK = 1
    ARTICLE = 2
    JOURNAL = 3
    WEBSITE = 4
    PUB_TYPE_CHOICES = (
        (BOOK, 'book'),
        (ARTICLE, 'article'),
        (JOURNAL, 'journal'),
        (WEBSITE, 'website'),
    )
    pub_type = models.IntegerField(
        choices=PUB_TYPE_CHOICES,
        default=1,
    )
    title = models.CharField(max_length=200)
    authors = models.ManyToManyField('Person', related_name='publication_authors_person', blank=True)
    editors = models.ManyToManyField('Person', related_name='publication_editors_person', blank=True)
    places = models.ManyToManyField('Place', blank=True)
    publisher = models.ForeignKey('Publisher', blank=True, null=True, on_delete=models.PROTECT)
    year = models.IntegerField(blank=True, null=True)#FlexibleDateField(blank=True, null=True)
    date = models.DateField(blank=True, null=True)
    url = models.URLField(blank=True)
    issn = models.CharField(max_length=200, blank=True)
    isbn = models.CharField(max_length=200, blank=True)
    doi = models.CharField(max_length=200, blank=True)
    issue = models.CharField(max_length=200, blank=True)
    volume = models.CharField(max_length=200, blank=True)
    pages = models.CharField(max_length=200, blank=True)
    included_in = models.ForeignKey('Publication', blank=True, null=True, on_delete=models.PROTECT, related_name='publication_included_in_publication')

    def __str__(self):
        return '{}: {} ({})'.format(self.get_authors(), self.title, self.get_pub_type_display())

    def get_authors(self):
        alist = list()
        for a in self.authors.all():
            alist.append(a.name)
        return ','.join(alist)


class Person(models.Model):
    name = models.CharField(max_length=200)
    firstnames = models.CharField(max_length=200)

    def __str__(self):
        return self.name

class Place(models.Model):
    name = models.CharField(max_length=200)

    def __str__(self):
        return self.name


class Publisher(models.Model):
    name = models.CharField(max_length=200)

    def __str__(self):
        return self.name

