import isbnlib

from django.shortcuts import render
from django.views.generic import ListView
from django.http import HttpResponseRedirect, HttpResponse
from django.shortcuts import redirect

from .models import Publication
from .forms import PublicationForm

def index(request):
    return render(request, 'publications/publication_list.html', {})

def get_object_urls(object_type):
    object_urls = dict()
    object_urls['add'] = object_type + '_edit_ic'
    object_urls['edit'] = object_type + '_edit_ic'
    object_urls['delete'] = object_type + '_delete_ic'
    return object_urls

def publication_search_ic(request):
    if request.method == 'POST':
        query = request.POST.get('search','')
        object_list = Publication.objects.filter(title__icontains=query)
        object_type = 'publication'
        return render(request, 'publications/object_list.html',
            {'object_list':object_list, 'object_type': object_type, 'object_urls': get_object_urls(object_type), })
    else:
        pass


def lookup_isbn(request, isbn):
    book = isbnlib.meta(isbn)
    return HttpResponse(book)


def publication_list_ic(request):
    object_list = Publication.objects.all()
    object_type = 'publication'
    return render(request, 'publications/object_list.html',
          {'object_list':object_list, 'object_type': object_type, 'object_urls': get_object_urls(object_type), })


def publication_delete_ic(request):
    if request.method == 'POST':
        pk = request.POST.get('pk', '')
        print(pk)
        publication = Publication.objects.get(id=pk)
        publication.delete()
        return HttpResponse('Publication deleted')
    return HttpResponse('Error')

def publication_edit_ic(request, pk=None):
    err = None
    updated = False
    object_type = 'publication'
    if pk:
        publication = Publication.objects.get(id=pk)
    else:
        publication = Publication()
    if request.method == 'POST':
        form = PublicationForm(request.POST, request.FILES, instance=publication)
        if form.is_valid():
            publication = form.save()
            publication.save()
            updated = True
        else:
            err = form.errors.as_data()
    else:
        form = PublicationForm(instance=publication)
    return render(request, 'publications/publication_edit.html',
          {'form': form, 'publication': publication, 'updated': updated, 'err': err, 'object_type': object_type, 'object_urls': get_object_urls(object_type), })

