from django import forms
from django.db import models
from django.contrib import admin
from django.contrib.auth.admin import UserAdmin

from ckeditor.widgets import CKEditorWidget

from django.contrib.auth.models import Group

from ddusers.models import User
from ddusers.models import User
from ddusers.models import Institution
from ddusers.models import Project
from ddusers.models import DataSet
#from ddusers.models import DataSetPublication
from ddusers.models import DataFile
from ddusers.models import DataType
from ddusers.models import Topic
from ddusers.models import Keyword
from ddusers.models import Country
from ddusers.models import ProtestEvent
from ddusers.models import City
from ddusers.models import Link
#from ddusers.models import Publication
from ddusers.models import WebPage
from ddusers.models import ReceptiveTo
from ddusers.models import Affiliation
from ddusers.models import KeywordTags
from ddusers.models import KeywordTagged
from ddusers.models import Category
from ddusers.models import Sponsor
from ddusers.models import Documentation
from ddusers.models import AnalysisMethodsTagged
from ddusers.models import AnalysisMethodsTags



from ddusers.models import EnTagged

admin.site.register(EnTagged)
admin.site.register(KeywordTags)
admin.site.register(KeywordTagged)
admin.site.register(AnalysisMethodsTagged)
admin.site.register(AnalysisMethodsTags)


class AffiliationInline(admin.TabularInline):
    model = Affiliation
    extra = 1

#class DataSetDescriptionInline(admin.StackedInline):
#    model = DataSetDescription
#    extra = 1


class DataFileInline(admin.TabularInline):
    model = DataFile
    extra = 1

class DataUserAdmin(UserAdmin, admin.ModelAdmin):
    #formfield_overrides = {
    #    models.TextField: {'widget': CKEditorWidget},
    #}
    model = User

    inlines = [
        AffiliationInline,
    ]

    fieldsets = UserAdmin.fieldsets + (
                     (None, {'fields': ( 'middle_name', 'external_profile', 'academic_title',  'image', 'access', 'topics', 'receptive_tos', 'countries', 'interests', 'en_tags', 'name_prefix', 'name_suffix')}),
                         )
    filter_horizontal = ['topics','countries', 'receptive_tos', ]

    def _access_choices(self, obj):
        return obj.get_access_display()
    _access_choices.short_description = 'Access'

    list_display = UserAdmin.list_display + ('_access_choices',)


#class ProjectAdminForm(forms.ModelForm):
#    content = forms.CharField(widget=CKEditorWidget())
#    fields ='__all__'
#    class Meta:
#        model = Project

class WebPageAdmin(admin.ModelAdmin):
    formfield_overrides = {
        models.TextField: {'widget': CKEditorWidget},
    }
    model = WebPage

class TopicAdmin(admin.ModelAdmin):
    formfield_overrides = {
        models.TextField: {'widget': CKEditorWidget},
    }
    model = Topic

class ReceptiveToAdmin(admin.ModelAdmin):
    model = ReceptiveTo

class KeywordAdmin(admin.ModelAdmin):
    formfield_overrides = {
        models.TextField: {'widget': CKEditorWidget},
    }
    model = Keyword

class InstitutionAdmin(admin.ModelAdmin):
    formfield_overrides = {
        models.TextField: {'widget': CKEditorWidget},
    }
    model = Institution

    #fields = ['public', 'name', 'original_name', 'short_name', 'department', 'address', 'postcode', 'city', 'country', 'location', 'website', 'image', 'image_large', 'description', 'short_description',]
    filter_horizontal = ['affiliated_users',]


class ProjectAdmin(admin.ModelAdmin):
    formfield_overrides = {
        models.TextField: {'widget': CKEditorWidget},
    }
    model = Project

    fields = ['name', 'url', 'user', 'group']

    #def _access_choices(self, obj):
    #    return obj.get_access_display()
    #_access_choices.short_description = 'Access'

    list_display = ('name', 'url',)

    # override save_model in admin
    # add user to project.group if he is not a member
    #def save_model(self, request, obj, form, change):
    #    try:
    #        obj.group
    #    except:
    #        obj.group = Group.objects.create(name=obj.title)
    #    if not request.user.groups.filter(id=obj.group.id).exists():
    #        request.user.groups.add(obj.group)
    #    obj.save()
#class DataSetDescriptionAdmin(admin.ModelAdmin):
#    formfield_overrides = {
#        models.TextField: {'widget': CKEditorWidget},
#    }
#    model = DataSetDescription
#
#    fieldsets = (
#                     (None,
#                        {'fields': ( 'description', 'dataset', 'creator', 'publication_date', 'date_of_data_creation',  'data_of_data_creation_text',)}
#                     ),
#                )
#    #filter_horizontal = ['topics','countries', 'receptive_tos', 'publications', ]

class CountryAdmin(admin.ModelAdmin):
    model = Country

    list_display = ('name', 'slug', 'geo_lat', 'geo_lng', 'public')

class DataSetAdmin(admin.ModelAdmin):
    #formfield_overrides = {
    #    models.TextField: {'widget': CKEditorWidget},
    #}
    inlines = [
        DataFileInline,
        #DataSetDescriptionInline,
    ]
    model = DataSet

    fields = ['user', ]
    #filter_horizontal = ['countries', 'keywords', ]
    #readonly_fields = ['html_string',]

    #def _access_choices(self, obj):
    #    return obj.get_access_display()
    #_access_choices.short_description = 'Access'

    #list_display = ('title', 'user', 'group' )
    # override save_model in admin
    # add user to project.group if he is not a member
    #def save_model(self, request, obj, form, change):
    #    try:
    #        obj.group
    #    except:
    #        obj.group = Group.objects.create(name=obj.title)
    #    if not request.user.groups.filter(id=obj.group.id).exists():
    #        request.user.groups.add(obj.group)
    #    obj.save()


class ProtestEventAdmin(admin.ModelAdmin):
    formfield_overrides = {
        models.TextField: {'widget': CKEditorWidget},
    }
    model = ProtestEvent

    filter_horizontal = ['cities', 'links', 'related_data', 'related_projects']

    list_display = ['country', 'get_cities', 'date_from', 'date_to']


admin.site.register(User, DataUserAdmin)
admin.site.register(Institution, InstitutionAdmin)
admin.site.register(Project, ProjectAdmin)

admin.site.register(DataSet, DataSetAdmin)
#admin.site.register(DataSetPublication)
admin.site.register(DataType)
admin.site.register(DataFile)
admin.site.register(Topic, TopicAdmin)
admin.site.register(ReceptiveTo, ReceptiveToAdmin)
admin.site.register(Keyword, KeywordAdmin)
admin.site.register(Country, CountryAdmin)
admin.site.register(ProtestEvent, ProtestEventAdmin)
admin.site.register(WebPage, WebPageAdmin)
admin.site.register(City)
admin.site.register(Link)
#admin.site.register(Publication)
admin.site.register(Affiliation)
admin.site.register(Sponsor)
admin.site.register(Category)
admin.site.register(Documentation)
